@@ -1,26 +1,25 @@
-import os
 import math
-from PIL import Image, ImageDraw, ImageFont
+import os
 
-from django.contrib.contenttypes.fields import GenericRelation
-from django.db import models
-from django.db.utils import OperationalError
+from PIL import Image, ImageDraw, ImageFont
 from django.conf import settings
+from django.contrib import auth
+from django.contrib.admin.models import ADDITION, CHANGE, DELETION
+from django.contrib.admin.models import LogEntry as BaseLogEntry
+from django.contrib.contenttypes.fields import GenericRelation
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import FieldError, ObjectDoesNotExist
+from django.db import models
+from django.db.utils import OperationalError
 from django.urls import reverse, NoReverseMatch
-from django.contrib import auth
-from django.contrib.admin.models import LogEntry as BaseLogEntry
-from django.contrib.admin.models import ADDITION, CHANGE, DELETION
 from django.utils.formats import localize
 from django.utils.timezone import utc
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from rest_framework import permissions as rest_permissions
 
 from mapentity.templatetags.mapentity_tags import humanize_timesince
+from .helpers import smart_urljoin, is_file_uptodate, capture_map_image, extract_attributes_html
 from .settings import app_settings, API_SRID
-from .helpers import smart_urljoin, is_file_newer, capture_map_image, extract_attributes_html
-
 
 # Used to create the matching url name
 ENTITY_LAYER = "layer"
@@ -71,9 +70,7 @@ class MapEntityRestPermissions(rest_permissions.DjangoModelPermissions):
     }
 
 
-class MapEntityMixin(models.Model):
-    attachments = GenericRelation(settings.PAPERCLIP_ATTACHMENT_MODEL)
-
+class BaseMapEntityMixin(models.Model):
     _entity = None
     capture_map_image_waitfor = '.leaflet-tile-loaded'
 
@@ -86,7 +83,7 @@ class MapEntityMixin(models.Model):
         if hasattr(name, '_proxy____args'):
             name = name._proxy____args[0]  # untranslated
         # Whole "add" phrase translatable, but not catched  by makemessages
-        return _(u"Add a new %s" % name.lower())
+        return _("Add a new %s" % name.lower())
 
     @classmethod
     def get_entity_kind_permission(cls, entity_kind):
@@ -144,7 +141,7 @@ class MapEntityMixin(models.Model):
         image_path = self.get_map_image_path()
         if os.path.exists(image_path):
             os.unlink(image_path)
-        super(MapEntityMixin, self).delete(*args, **kwargs)
+        super().delete(*args, **kwargs)
 
     @classmethod
     def get_layer_url(cls):
@@ -201,7 +198,7 @@ class MapEntityMixin(models.Model):
     def prepare_map_image(self, rooturl):
         path = self.get_map_image_path()
         # Do nothing if image is up-to-date
-        if is_file_newer(path, self.get_date_update()):
+        if is_file_uptodate(path, self.get_date_update()):
             return False
         if self.get_geom() is None:
             size = app_settings['MAP_CAPTURE_SIZE']
@@ -266,7 +263,14 @@ class MapEntityMixin(models.Model):
         return False
 
 
-class LogEntry(MapEntityMixin, BaseLogEntry):
+class MapEntityMixin(BaseMapEntityMixin):
+    attachments = GenericRelation(settings.PAPERCLIP_ATTACHMENT_MODEL)
+
+    class Meta:
+        abstract = True
+
+
+class LogEntry(BaseMapEntityMixin, BaseLogEntry):
     geom = None
     object_verbose_name = _("object")
 
@@ -284,18 +288,18 @@ class LogEntry(MapEntityMixin, BaseLogEntry):
 
     @property
     def action_time_display(self):
-        return u'{0} ({1})'.format(localize(self.action_time),
-                                   humanize_timesince(self.action_time))
+        return '{0} ({1})'.format(localize(self.action_time),
+                                  humanize_timesince(self.action_time))
 
     @property
     def object_display(self):
-        model_str = u"{}".format(self.content_type)
+        model_str = str(self.content_type)
         try:
             obj = self.get_edited_object()
             assert obj._entity, 'Unregistered model %s' % model_str
             obj_url = obj.get_detail_url()
         except (ObjectDoesNotExist, NoReverseMatch, AssertionError):
-            return u'%s %s' % (model_str, self.object_repr)
+            return '%s %s' % (model_str, self.object_repr)
         else:
-            return u'<a data-pk="%s" href="%s" >%s %s</a>' % (
+            return '<a data-pk="%s" href="%s" >%s %s</a>' % (
                 obj.pk, obj_url, model_str, self.object_repr)
